@@ -18,6 +18,7 @@
 # Copyright (c) OWASP Foundation. All Rights Reserved.
 
 import json
+from typing import Union
 
 from . import BaseOutput
 from .schema import BaseSchemaVersion, SchemaVersion1Dot0, SchemaVersion1Dot1, SchemaVersion1Dot2, SchemaVersion1Dot3
@@ -29,7 +30,7 @@ class Json(BaseOutput, BaseSchemaVersion):
     def output_as_string(self) -> str:
         return json.dumps(self._get_json())
 
-    def _get_json(self) -> dict:
+    def _get_json(self) -> object:
         components = list(map(self._get_component_as_dict, self.get_bom().get_components()))
 
         response = {
@@ -45,8 +46,9 @@ class Json(BaseOutput, BaseSchemaVersion):
 
         return response
 
-    def _get_component_as_dict(self, component: Component) -> dict:
-        c = {
+    def _get_component_as_dict(self, component: Component) -> object:
+        c: dict[str, Union[str, list[dict[str, str]], list[dict[str, dict[str, str]]], list[
+            dict[str, Union[str, list[dict[str, str]]]]]]] = {
             "type": component.get_type().value,
             "name": component.get_name(),
             "version": component.get_version(),
@@ -54,10 +56,10 @@ class Json(BaseOutput, BaseSchemaVersion):
         }
 
         if component.get_namespace():
-            c['group'] = component.get_namespace()
+            c['group'] = str(component.get_namespace())
 
         if component.get_hashes():
-            hashes = []
+            hashes: list[dict[str, str]] = []
             for component_hash in component.get_hashes():
                 hashes.append({
                     "alg": component_hash.get_algorithm().value,
@@ -66,30 +68,31 @@ class Json(BaseOutput, BaseSchemaVersion):
             c['hashes'] = hashes
 
         if component.get_license():
-            c['licenses'] = [
+            licenses: list[dict[str, dict[str, str]]] = [
                 {
                     "license": {
-                        "name": component.get_license()
+                        "name": str(component.get_license())
                     }
                 }
             ]
+            c['licenses'] = licenses
 
         if self.component_supports_author() and component.get_author():
-            c['author'] = component.get_author()
+            c['author'] = str(component.get_author())
 
         if self.component_supports_external_references() and component.get_external_references():
-            c['externalReferences'] = []
+            ext_references: list[dict[str, Union[str, list[dict[str, str]]]]] = []
             for ext_ref in component.get_external_references():
-                ref = {
+                ref: dict[str, Union[str, list[dict[str, str]]]] = {
                     "type": ext_ref.get_reference_type().value,
                     "url": ext_ref.get_url()
                 }
 
                 if ext_ref.get_comment():
-                    ref['comment'] = ext_ref.get_comment()
+                    ref['comment'] = str(ext_ref.get_comment())
 
                 if ext_ref.get_hashes():
-                    ref_hashes = []
+                    ref_hashes: list[dict[str, str]] = []
                     for ref_hash in ext_ref.get_hashes():
                         ref_hashes.append({
                             "alg": ref_hash.get_algorithm().value,
@@ -97,35 +100,36 @@ class Json(BaseOutput, BaseSchemaVersion):
                         })
                     ref['hashes'] = ref_hashes
 
-                c['externalReferences'].append(ref)
+                ext_references.append(ref)
+            c['externalReferences'] = ext_references
 
         return c
 
-    def _get_metadata_as_dict(self) -> dict:
+    def _get_metadata_as_dict(self) -> object:
         bom_metadata = self.get_bom().get_metadata()
-        metadata = {
+        metadata: dict[str, Union[str, list[dict[str, Union[str, list[dict[str, str]]]]]]] = {
             "timestamp": bom_metadata.get_timestamp().isoformat()
         }
 
-        if self.bom_metadata_supports_tools() and len(bom_metadata.get_tools()) > 0:
-            metadata['tools'] = []
+        if self.bom_metadata_supports_tools():
+            tools: list[dict[str, Union[str, list[dict[str, str]]]]] = []
             for tool in bom_metadata.get_tools():
-                tool_dict = {
+                tool_dict: dict[str, Union[str, list[dict[str, str]]]] = {
                     "vendor": tool.get_vendor(),
                     "name": tool.get_name(),
                     "version": tool.get_version()
                 }
 
                 if len(tool.get_hashes()) > 0:
-                    hashes = []
+                    hashes: list[dict[str, str]] = []
                     for tool_hash in tool.get_hashes():
                         hashes.append({
                             "alg": tool_hash.get_algorithm().value,
                             "content": tool_hash.get_hash_value()
                         })
                     tool_dict['hashes'] = hashes
-
-                metadata['tools'].append(tool_dict)
+                tools.append(tool_dict)
+            metadata['tools'] = tools
 
         return metadata
 
