@@ -29,11 +29,14 @@ The Environment Parsers support population of the following data about Component
 """
 
 import sys
+from pkg_resources import DistInfoDistribution  # type: ignore
 
 if sys.version_info >= (3, 8, 0):
     from importlib.metadata import metadata
+    import email
 else:
-    from importlib_metadata import metadata
+    from importlib_metadata import metadata  # type: ignore
+    import email
 
 from . import BaseParser
 
@@ -47,12 +50,12 @@ class EnvironmentParser(BaseParser):
     Best used when you have virtual Python environments per project.
     """
 
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__()
 
         import pkg_resources
 
-        i: pkg_resources.DistInfoDistribution
+        i: DistInfoDistribution
         for i in iter(pkg_resources.working_set):
             c = Component(name=i.project_name, version=i.version)
 
@@ -63,14 +66,15 @@ class EnvironmentParser(BaseParser):
             if 'License' in i_metadata.keys() and i_metadata.get('License') != 'UNKNOWN':
                 c.set_license(license_str=i_metadata.get('License'))
 
-            for classifier in i_metadata.get_all('Classifier'):
-                if str(classifier).startswith('License :: OSI Approved :: '):
-                    c.set_license(license_str=str(classifier).replace('License :: OSI Approved :: ', '').strip())
+            if 'Classifier' in i_metadata.keys():
+                for classifier in i_metadata.get_all('Classifier'):
+                    if str(classifier).startswith('License :: OSI Approved :: '):
+                        c.set_license(license_str=str(classifier).replace('License :: OSI Approved :: ', '').strip())
 
             self._components.append(c)
 
     @staticmethod
-    def _get_metadata_for_package(package_name: str):
+    def _get_metadata_for_package(package_name: str) -> email.message.Message:
         if sys.version_info >= (3, 8, 0):
             return metadata(package_name)
         else:
